function obj=copy(obj,varargin)
% copy - create new deflate object and copy elements into it.
% CALL
%     D=copy(D,I1,I2,..)
%     D=copy(D,I1,':',..)
% 
%  %test this routine
%     N=1200;
%     adata=rand(N);
%     a=deflate(adata);
%     I1=[2:7:N];
%     I2=[2:3:N];
%     b=a(I1,I2);
%     bb=copy(a,I1,I2);
%     is_eq(adata(I1,I2),b);
%     bbb=full(bb);
%     is_eq(adata(I1,I2),bbb);

ind=substruct('()',varargin);
[subscript,OOB]=getSubscript(ind,obj.size);
if OOB
    error('Index exceeds matrix dimensions.');
end

%compute the total number of required indices
for k=1:length(varargin) 
    dims(k)=length(varargin{k});
end

%determine linear indices
if prod(dims)*(sizeof(obj)+4)<16*10^6;
    %     do all in one go with efficient algorithm
    linIndices = sub2indVector(obj.size,subscript{:});

    %initialize new vector, but copy all properties of old vector except "N"
    %and "segment"
    olddata=obj.data(linIndices);
    obj.data=reset(obj.data);
    obj.data(numel(olddata))=olddata(end); %WIJZ ZIJPP: set correct size
    obj.data(:)=olddata;
    obj.size=dims;
else
    %apply a number of small steps
    %assign elements of new vector in loop    
    N=prod(dims);
    %initialize new vector, but copy all properties of old vector except "N"
    %and "segment"
    newvector=reset(obj.data);
    newvector=set(newvector,'N',N);
        
    %copy values to vector
    SEGSIZE    = get(obj.data,'segmentSize');
    MAXSEGMENT =floor(4*10^6/(SEGSIZE*(sizeof(obj.data)+8))); %maximimum number of segment to write in one go
    strt=1;
    while strt<=N
        last=min(strt+MAXSEGMENT*SEGSIZE-1,N);        
        dprintf('copy range %10d - %10d from %d',strt,last,N);
        rng=uint32(strt):uint32(last); %elements required for new matrix. 
        %         These are store in uint32 because this saves 4 bytes
        %         compared to double, and only integers are needed. Using
        %         Singles will result in error in subsasgn.
        
        oldrng=sub2indVector2(obj.size,rng,subscript{:});
        newvector(rng)=obj.data(oldrng);
        strt=last+1;
    end
    obj.data=newvector;    
    obj.size=dims;
end