function obj = ctranspose(obj)
% ctranspose - transpose deflated matrix 
%
% This method transposes  a deflated matrix. Two methods for  It uses the on-disk method,
% which means that data are dumped to temporary files and a new matrix is
% built from these files. This is generally faster then the in-memeory
% method (see ctransposeMemory).
%
% CALL:
%  T = transpose(obj)
% 
% INPUT:
%  obj:     <object>  deflate object
% 
% OUTPUT:
%  obj:       <object> transposed deflate object
%
% TEST
%     adata=rand(200000,20);
%     nw=now;
%     a=deflate(adata);
%     dprintf('T1=%f',86400*(now-nw));%  bdata=full(ctransposeDisk(a));
%     bdata=full(a');
%     dprintf('T2=%f',86400*(now-nw));
%     is_eq(adata',bdata);
%     ==> T2=19 sec

if length(obj.size)>2
    error('Transpose on ND array is not defined.');
end
% length(obj.size)==2;
if any(obj.size==1)||any(obj.size==0)
    %rearranging elements not needed
    obj.size=[obj.size(2),obj.size(1)];
    return
end

% Decide on method
% Get available memory (in bytes):
b=availableMemory;

% Get size of object
objsize=sizeof(obj)*numel(obj);

%If object is small enough, expand to full matrix, transpose, and store
%again. To do this object must fit into memory at least twice
if 2*objsize<b
    M=full(obj);
    obj.data=set(obj.data,'data',[]); %free memory
    M=M';
    obj.data=set(obj.data,'data',M); %force right size

    obj.size=[obj.size(2),obj.size(1)];
    return
end
%else use on-disk or in memory method.
%on-disk method is recommended
obj=ctransposeDisk(obj);


