% script testdeflate
% script to test methods of deflate class
% Copy to command line to execute
% Benchmark on Dual core machine

%ZLIB 122
% Matlab 2006b, use java compress, uncompress dll: 49.93 sec
% Matlab 2006b, use compress dll, uncompress dll: 62.15 sec
% Matlab 2006b, use compress mexw32, uncompress mexw32: 46.9070 sec
%ZLIB 125
% Matlab 2006b, use java compress, uncompress dll: 46.219000 sec
% Matlab 2006b, use compress mexw32, uncompress mexw32: 44.094000

T0 = clock;  
%--------------------------------------
%TEST SUBSCRIPTING
a=rand(1000,500);
ad=deflate(a,'segments',1000);
rng1=1:size(ad,1); %closed range
rng2=1:size(ad,2);
tic
aref=ad(rng1,rng2);
is_eq(a(rng1,rng2),aref);
dprintf('Subscript closed range: %f',toc);
rng1(2)=[]; %closed range
tic
aref=ad(rng1,rng2);
is_eq(a(rng1,rng2),aref);
dprintf('Subscript open range: %f',toc);


% TEST: CONSTRUCTOR; METHOD FULL
%simple transpose
a=rand(1000,500);
ad=deflate(a);
adt=ad';
is_eq(full(adt),a');
%--------------------------------------
%compare speeds
% TEST: CONSTRUCTOR; METHOD CTRANSPOSEDISK
a=rand(37000,200);
nw=now;
ad=deflate(a);
dprintf('Tdeflate=%f',86400*(now-nw));
nw=now;
b=full(ctransposeDisk(ad));
% b=full(ctransposeMemory(ad)');
dprintf('Ttranspose=%f',86400*(now-nw));
at=a';
is_eq(at,b);

%_________________
% TEST: CONSTRUCTOR BASED ON STRUCT
%check conversion to struc and constructor
a=rand(1000);
a1=deflate(a);
a_struct=struct(a1);
a2=deflate(a_struct);
is_eq(full(a1),full(a2));

%_________________

% TEST: CTRANSPOSEDISK (MODE MEMORY)
a=rand(2000);
a1=deflate(a,'mode','memory');
tic
at1=a1';
toc
tic
at2=ctransposeDisk(a1);
toc
is_eq(full(at1),full(at2))
%_________________

% TEST: CTRANSPOSEDISK (MODE COMPRESSED)
a=rand(1500);
a1=deflate(a,'mode','com');
tic
at1=a1';
toc
tic
at2=ctransposeDisk(a1);
toc
is_eq(full(at1),full(at2))

%________________________________________
% TEST: METHOD COPY
a=rand(1537);
a1=deflate(a,'mode','com');
rng1=1:1411;
rng2=1:1377;
a2=copy(a1,rng1,rng2);
a3=a(rng1,rng2);
is_eq(a3,full(a2));
%

tic
a=rand(1137,2000);
b=deflate('size',size(a),'segm',1137);
STEP=137;
vRng=1:1137;
for k=1:STEP:size(a,2)
    rng=k:min(k+STEP-1,size(a,2));
    b(:,rng)=a(:,rng);
    %     b(vRng,rng)=a(:,rng);
end
is_eq(a,full(b));
toc
%____________
a=rand(1137,20);
b=deflate('size',size(a),'segm',1137);
cc=rand(1137,31);
b(:,10:40)=cc;
is_eq(b(:,10:40),cc);

disp(sprintf('Total time: %f',etime(clock, T0)));


