function [B,M]=groupIndex(a,expectedGroupSize)
% groupIndex - identify unique groups and get corresponding index ranges.
% Input must be sorted
% 
% CALL
%     [B,M]=groupIndex(VALUES)
%     
% INPUT
%     VALUES (nx1): sorted vector
%     
% OUTPUT
%     B(n x 1):  common value for group
%     M(n x 1): M(:,1)= first index
%               M(:,2)= last index
%     
% SEE ALSO
%     group, unique
    
% if nargin==0
%     VALUES=uint32(ones(4000,1)*(1:1000));
%     VALUES=VALUES(:);
%     tic;
%     [B,M]=groupIndex(VALUES);
%     toc
%     B=[];
%     M=[];
%     return
% end

if nargin<2
    expectedGroupSize=1000;
end

numelA = length(a);
if numel(a)~=numelA
    error('MATLAB:issorted:AvectorOrRowsFlag',...
        'A must be a vector or ''rows'' must be specified.');
end
a=a(:);


% FOR loop breaks if it encounters something out of order
OKRUN=false;
MEMCLAIM=1+ceil(numelA/expectedGroupSize);

while OKRUN==false
    try
        GrpStrt=zeros(MEMCLAIM,1,'uint32');
        N=1;
        GrpStrt(N)=1;
        for i = 1:numelA-1
            if a(i) ~= a(i+1)
                %i+1 starts a new group
                N=N+1;
                GrpStrt(N)=GrpStrt(N)+i+1;
                %This is the fastest construction
                %Introducing an extra if decrease speed
            end
        end
        OKRUN=true;
    catch
        MEMCLAIM=min(2*MEMCLAIM,numelA);
    end
end
GrpStrt(N+1)=length(a)+1;
B = a(GrpStrt(1:N));
M = [GrpStrt(1:N),GrpStrt(2:(N+1))-1];

% PREVIOUS IMPLEMENTATION
%         function [B,M]=groupIndex(VALUES)
% 
%         %make sure we are dealing with vector:
%         VALUES=reshape(VALUES,numel(VALUES),1);
% 
%         %get uinque VALUES
%         [B,lastB]=unique(VALUES);
%         % B: contains unique values, sorted
%         % lastB: contains last index corresponding to B
% 
%         lastB=makeIndex(lastB);
%         M=[ [1;lastB(1:end-1)+1] , lastB];
% 
%         function lastB=makeIndex(lastB)
%         if lastB(end)>intmax('uint16')
%             lastB=uint32(lastB); %4 byte storage
%         elseif lastB(end)>intmax('uint8')
%             lastB=uint16(lastB); %2 byte storage
%         else
%             lastB=uint8(lastB); %1 byte storage
%         end

%Inefficient implementation    
%     M=zeros(length(blks),3,'uint32');
%     if isempty(blks)
%         return
%     end
%     B=1;
%     BLK=blks(1);
%     M(B,1)=BLK;
%     M(B,2)=1;  % start index
%     ROW=1;
%     SORTED=true;
%     for bb=blks(2:end)
%         ROW=ROW+1; %bb=blks(ROW)
%         if bb~=BLK
%             %close previous BLOCK
%             M(B,3)=ROW-1;  % start index
% 
%             B=B+1;%focus on next BLOCK     
%             %B: current open block
%             if bb<BLK
%                 SORTED=false;
%             end
%             BLK=bb;
%             M(B,1)=BLK;
%             M(B,2)=ROW;
%         end
%     end
%     %close last BLOCK
%     M(B,3)=ROW-1;  % start index
%     M(B:end,:)=[];
